@@ -1,35 +1,15 @@
-( cd opt/kde/share/doc/HTML/sk/ark ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/ark ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kdf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kdf ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kdm ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kit ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/ktuberling ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/ktuberling ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/amor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/amor ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/karm ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/karm ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kate ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kate ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kdat ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kdat ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kdvi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kdvi ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kmix ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kmix ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kodo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kodo ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kolf ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kolf ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kpat ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kpat ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kppp ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kppp ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/krec ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/krec ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/krfb ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/krfb ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/ksim ; rm -rf common )
@@ -44,40 +24,18 @@
 ( cd opt/kde/share/doc/HTML/sk/kbattleship ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kaboodle ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kaboodle ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kfloppy ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kfloppy ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/khexedit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/khexedit ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kpercentage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kpercentage ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kandy ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kandy ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kcalc ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kcalc ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kdesu ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kcron ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kcron ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kedit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kedit ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kfind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kfind ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kjots ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kjots ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kmoon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kmoon ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kooka ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kooka ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/ksame ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/ksame ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/ksysv ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/ksysv ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/ktron ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/ktron ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kuser ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kuser ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kview ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kview ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kwin4 ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kwin4 ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/lskat ; rm -rf common )
@@ -86,12 +44,8 @@
 ( cd opt/kde/share/doc/HTML/sk/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/klipper ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/klipper ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/ksnapshot ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kompare ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kpackage ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kpackage ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/khelpcenter/faq ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/khelpcenter/quickstart ; rm -rf common )
@@ -110,12 +64,8 @@
 ( cd opt/kde/share/doc/HTML/sk/ksirtet ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/konquest ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/konquest ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kspaceduel ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kweather ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kwuftpd ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kmenuedit ; rm -rf common )
@@ -126,8 +76,6 @@
 ( cd opt/kde/share/doc/HTML/sk/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kxconfig ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kxconfig ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/sk/common ; rm -rf qpl-license.html )
@@ -164,6 +112,8 @@
 ( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/sk/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/sk/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/sk/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/sk/common ; rm -rf doxygen.css )
@@ -178,12 +128,16 @@
 ( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/sk/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/sk/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/sk/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/sk/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/sk/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/sk/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/sk/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/sk/common ; rm -rf fdl-license.html )
@@ -316,8 +270,6 @@
 ( cd opt/kde/share/doc/HTML/sk/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmtaskbar ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kcontrol/kthememgr ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmfontinst ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kicker-applets ; rm -rf common )
@@ -330,8 +282,6 @@
 ( cd opt/kde/share/doc/HTML/sk/kdeprint ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kasteroids ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kasteroids ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kmessedwords ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kicker ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/klines ; rm -rf common )
@@ -342,10 +292,6 @@
 ( cd opt/kde/share/doc/HTML/sk/kmplot ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kpager ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kpaint ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kpaint ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kpoker ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kpoker ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kruler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kruler ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/ksnake ; rm -rf common )
@@ -354,36 +300,20 @@
 ( cd opt/kde/share/doc/HTML/sk/kspell ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/ktimer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/ktimer ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/megami ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/megami ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kreversi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kreversi ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/noatun ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/noatun ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kdebugdialog ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kblackbox ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kblackbox ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kcharselect ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kuickshow ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kuickshow ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kiconedit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kiconedit ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kfouleggs ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kaphorism ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kaphorism ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kghostview ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kghostview ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/klickety ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/klickety ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kjumpingcube ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kenolaba ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kenolaba ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kgpgcertmanager ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kworldclock ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/ksokoban ; rm -rf common )
